Fake Blender Python API module collection: fake-bpy-module
==========================================================

fake-bpy-module is the collections of the fake Blender Python API
modules for the code completion in commonly used IDEs.

.. figure:: https://raw.githubusercontent.com/nutti/fake-bpy-module/master/docs/images/fake-bpy-module_thumbnail.png
   :alt: 

Install
-------

| fake-bpy-module is registered to PyPI.
| You can install it as a pip package.

.. code:: sh

    pip install fake-bpy-module-<version>

If you install fake-bpy-module for Blender 2.8, run below command.

.. code:: sh

    pip install fake-bpy-module-2.80

Supported Blender Version
~~~~~~~~~~~~~~~~~~~~~~~~~

+-----------+--------+
| Version   | PyPI   |
+===========+========+
| 2.78      |        |
+-----------+--------+
| 2.78a     |        |
+-----------+--------+
| 2.78b     |        |
+-----------+--------+
| 2.78c     |        |
+-----------+--------+
| 2.79      |        |
+-----------+--------+
| 2.79a     |        |
+-----------+--------+
| 2.79b     |        |
+-----------+--------+
| 2.80      |        |
+-----------+--------+

Generate Modules Manually
~~~~~~~~~~~~~~~~~~~~~~~~~

You can also generate the modules manually. See `Generate
Module <https://github.com/nutti/fake-bpy-module/blob/master/docs/generate_modules.md>`__.

Bug report / Feature request / Disscussions
-------------------------------------------

If you want to report bug, request features or discuss about this
add-on, see
`ISSUES.md <https://github.com/nutti/fake-bpy-module/blob/master/ISSUES.md>`__.

Contribution
------------

If you want to contribute to this project, see
`CONTRIBUTING.md <https://github.com/nutti/fake-bpy-module/blob/master/CONTRIBUTING.md>`__.
